==> djangoldp_needle-0.1.42-py3-none-any.whl: djangoldp_needle/tests/test_booklets_list.py <==
import requests_mock
from django.db import transaction
from djangoldp_account.models import LDPUser
from rest_framework.test import APITestCase, APIClient, APITransactionTestCase
import json
import datetime
from pkg_resources import resource_string

from ..models import Booklet

from .data.target_url.realsites import real_sites

from .data.target_url.needlerealsites import needle_real_sites


class TestBookletList(APITestCase):

    def setUp(self):
        self.client = APIClient()

    def buildUser(self, username):
        user = LDPUser(email=username + '@test.startinblox.com', first_name='Test', last_name='Mactest',
                       username=username,
                       password='glass onion')
        user.save()
        return user

    def test_booklet_list_as_owner(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user1], [user2])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)

    def test_booklet_list_as_contributor(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user2], [user1])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)


    def test_booklet_list_hide_as_non_owner(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user2], [])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 0)

    def test_booklet_list_hide_as_non_contributor(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([], [user2])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 0)


    def store_booklet(self, owners, contributors):
        booklet = Booklet(
            title="title",
            abstract="",
            accessibility_public=False,
            collaboration_allowed=False,
            cover=1,
        )
        booklet.save()
        for owner in owners:
            booklet.owners.add(owner)
        for contributor in contributors:
            booklet.contributors.add(contributor)

==> djangoldp_needle-0.1.53-py3-none-any.whl: djangoldp_needle/tests/test_booklets_list.py <==
import requests_mock
from django.db import transaction
from djangoldp_account.models import LDPUser
from rest_framework.test import APITestCase, APIClient, APITransactionTestCase
import json
import datetime
from pkg_resources import resource_string

from ..models import Booklet

from .data.target_url.realsites import real_sites

from .data.target_url.needlerealsites import needle_real_sites


class TestBookletList(APITestCase):

    def setUp(self):
        self.client = APIClient()

    def buildUser(self, username):
        user = LDPUser(email=username + '@test.startinblox.com', first_name='Test', last_name='Mactest',
                       username=username,
                       password='glass onion')
        user.save()
        return user

    def test_booklet_list_as_owner(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user1], [user2])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)

    def test_booklet_list_as_contributor(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user2], [user1])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)


    def test_booklet_list_hide_as_non_owner(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user2], [])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 0)

    def test_booklet_list_hide_as_non_contributor(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([], [user2])
        self.client.force_authenticate(user1)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 0)

    def test_booklet_list_as_authenticated_collaboration_allowed(self):
        user1 = self.buildUser('user1')
        user2 = self.buildUser('user2')
        self.store_booklet([user1], [], collaboration=True)
        self.client.force_authenticate(user2)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)

    def test_booklet_list_hide_non_public_for_anonymous(self):
        user1 = self.buildUser('user1')
        self.store_booklet([user1], [])

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 0)

    def test_booklet_list_show_public_for_anonymous(self):
        user1 = self.buildUser('user1')
        self.store_booklet([user1], [], public=True)

        response = self.client.get(
            "/booklets/",
            content_type='application/ld+json',
        )
        response_value = response.json()
        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(response_value['ldp:contains']), 1)


    def store_booklet(self, owners, contributors, public = False, collaboration = False):
        booklet = Booklet(
            title="title",
            abstract="",
            accessibility_public=public,
            collaboration_allowed=collaboration,
            cover=1,
        )
        booklet.save()
        for owner in owners:
            booklet.owners.add(owner)
        for contributor in contributors:
            booklet.contributors.add(contributor)

        return booklet
